#
# spec file for package python-urllib3
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-urllib3
Version:        1.16
Release:        2.3
Summary:        HTTP library with thread-safe connection pooling, file post, and more
License:        MIT
Group:          Development/Languages/Python
Url:            http://urllib3.readthedocs.org/
Source:         https://pypi.io/packages/source/u/urllib3/urllib3-%{version}.tar.gz
# PATCH-FIX-OPENSUSE speilicke@suse.com -- We need no coverage report
Patch1:         urllib3-test-no-coverage.patch
# PATCH-FEATURE-UPSTREAM -- use set_default_verify_paths() if no certificate path is supplied
Patch2:         urllib3-ssl-default-context.patch
# PATCH-FIX-OPENSUSE -- do not use unsupported SSLv3 in tests
Patch3:         urllib3-test-ssl-drop-sslv3.patch
BuildRequires:  python-PySocks
#!BuildIgnore: python-requests
BuildRequires:  python-devel
BuildRequires:  python-mock >= 1.3.0
BuildRequires:  python-nose >= 1.3.7
BuildRequires:  python-nose-exclude >= 0.4.1
BuildRequires:  python-tornado >= 4.2.1
Recommends:     python-pyOpenSSL
Recommends:     python-pyasn1
Recommends:     python-ndg-httpsclient
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Highlights

- Re-use the same socket connection for multiple requests
  (HTTPConnectionPool and HTTPSConnectionPool)
  (with optional client-side certificate verification).
- File posting (encode_multipart_formdata).
- Built-in redirection and retries (optional).
- Supports gzip and deflate decoding.
- Thread-safe and sanity-safe.
- Works with AppEngine, gevent, and eventlib.
- Tested on Python 2.6+ and Python 3.3+, 100% unit test coverage.
- Small and easy to understand codebase perfect for extending and building upon.
  For a more comprehensive solution, have a look at
  Requests which is also powered by urllib3.

%prep
%setup -q -n urllib3-%{version}
%patch1 -p1
%patch2 -p1
%if %(python -c "import ssl; print(hasattr(ssl,'PROTOCOL_TLSv1_2'))") == "True"
%patch3 -p1
%endif

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
rm -rf build
PYTHONPATH="%{buildroot}%{python_sitelib}" nosetests \
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestHTTPProxyManager.test_https_proxy_timeout \
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestHTTPProxyManager.test_https_proxy_pool_timeout \
%if 0%{?suse_version} && 0%{?suse_version} <= 1320
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestIPv6HTTPProxyManager.test_basic_ipv6_proxy \
%endif
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestHTTPProxyManager.test_headerdict \
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestHTTPProxyManager.test_headers \
	--exclude-test=test.with_dummyserver.test_poolmanager.TestPoolManager.test_headers \
	--exclude-test=test.with_dummyserver.test_https.TestHTTPS_IPv6Addr \
	--exclude-test=test.with_dummyserver.test_proxy_poolmanager.TestIPv6HTTPProxyManager

#%pre
# previous versions of the package installed .egg-info as a directory,
# the new update now installs it as a file. Clean out the directory, should it exist.
#if [ -d %{python_sitelib}/urllib3-%{version}-py*.egg-info ]; then
#  rm -rf %{python_sitelib}/urllib3-%{version}-py*.egg-info
#fi

%files
%defattr(-,root,root,-)
%doc CHANGES.rst CONTRIBUTORS.txt LICENSE.txt README.rst
%{python_sitelib}/urllib3
%{python_sitelib}/urllib3-%{version}-py*.egg-info

%changelog
* Thu Sep  1 2016 tbechtold@suse.com
- update to 1.16:
  * Disable IPv6 DNS when IPv6 connections are not possible. (Issue #840)
  * Provide ``key_fn_by_scheme`` pool keying mechanism that can be
    overridden. (Issue #830)
  * Normalize scheme and host to lowercase for pool keys, and include
    ``source_address``. (Issue #830)
  * Cleaner exception chain in Python 3 for ``_make_request``.
    (Issue #861)
  * Fixed installing ``urllib3[socks]`` extra. (Issue #864)
  * Fixed signature of ``ConnectionPool.close`` so it can actually safely be
    called by subclasses. (Issue #873)
  * Retain ``release_conn`` state across retries. (Issues #651, #866)
  * Add customizable ``HTTPConnectionPool.ResponseCls``, which defaults to
    ``HTTPResponse`` but can be replaced with a subclass. (Issue #879)
- Use pypi.io as Source url
* Fri May 20 2016 dmueller@suse.com
- update to 1.15.1:
  * Fix packaging to include backports module. (Issue #841)
  * Added Retry(raise_on_status=False). (Issue #720)
  * Always use setuptools, no more distutils fallback. (Issue #785)
  * Dropped support for Python 3.2. (Issue #786)
  * Chunked transfer encoding when requesting with ``chunked=True``.
  * Fixed regression with IPv6 port parsing. (Issue #801)
  * Append SNIMissingWarning messages to allow users to specify it in
    the PYTHONWARNINGS environment variable. (Issue #816)
  * Handle unicode headers in Py2. (Issue #818)
  * Log certificate when there is a hostname mismatch. (Issue #820)
  * Preserve order of request/response headers. (Issue #821)
* Wed Mar  2 2016 jmatejek@suse.com
- change Requires on pyopenssl, pyasn1 into Recommends,
  add ndg-httpsclient as well
  (these are dependencies of urrlib3's pyopenssl module, which can be
  used if native python's ssl capabilities are not good enough)
* Thu Feb 11 2016 aplanas@suse.com
- Update 1.14 source tar.gz from the source
  * Rebase urllib3-test-no-coverage.patch
* Tue Jan  5 2016 hpj@urpla.net
- Update to Version 1.14 (2015-12-29)
  * contrib: SOCKS proxy support! (Issue #762)
  * Fixed AppEngine handling of transfer-encoding header and bug in
    Timeout defaults checking. (Issue #763)
- Update to Version 1.13.1 (2015-12-18)
  * Fixed regression in IPv6 + SSL for match_hostname. (Issue #761)
- Update to Version 1.13 (2015-12-14)
  * Fixed pip install urllib3[secure] on modern pip. (Issue #706)
  * pyopenssl: Fixed SSL3_WRITE_PENDING error. (Issue #717)
  * pyopenssl: Support for TLSv1.1 and TLSv1.2. (Issue #696)
  * Close connections more defensively on exception. (Issue #734)
  * Adjusted read_chunked to handle gzipped, chunk-encoded bodies
    without repeatedly flushing the decoder, to function better on
    Jython. (Issue #743)
  * Accept ca_cert_dir for SSL-related PoolManager configuration.
    (Issue #758)
- removed ready-event.patch: applied upstream
- disabled more dysfunctional tests
* Mon Nov 16 2015 hpj@urpla.net
- restored ability to build with openSUSE <= 13.2
* Tue Oct 27 2015 jmatejek@suse.com
- removed python-certifi dependency, we don't want to use it
- drop 0001-Don-t-pin-dependency-to-exact-version.patch because it's
  not needed anymore
- re-enable tests, re-add relevant dependencies
  * don't exclude test_util.py
  * exclude proxy timeout tests that fail for spurious reasons
- urllib3-ssl-default-context.patch - use set_default_verify_paths()
  if no certificate path specified and verification not explicitly
  disabled
- urllib3-test-ssl-drop-sslv3.patch - don't use "SSLv3" constants
  in python 2.7.9 and up
- ready-event.patch - fix race conditions in timeout tests
- drop %%pre section because apparently "egg-info as file" is no longer
  true and this breaks builds
* Wed Oct 14 2015 toddrme2178@gmail.com
- Delete the system egg-info during pre phase: older versions of
  the package installed it as a directory, the latest update
  creates a file, and rpm has known issues with replacing this.
* Tue Oct  6 2015 hpj@urpla.net
- add python-pyOpenSSL, python-certifi and python-pyasn1 requirements
* Tue Oct  6 2015 hpj@urpla.net
- Comment out test requirements, as tests are disabled anyway, and
  one of these packages depend on python-requests, which depends on
  this package resulting in a circular dependency for openSUSE <= 13.1
* Fri Sep 25 2015 p.drouand@gmail.com
- Update to version 1.12
  * Rely on six for importing httplib to work around conflicts with
    other Python 3 shims. (Issue #688)
  * Add support for directories of certificate authorities, as
    supported by OpenSSL. (Issue #701)
  * New exception: NewConnectionError, raised when we fail to
    establish a new connection, usually ECONNREFUSED socket error.
- Fix version dependencies
- Add new build requirements following upstream changes
  * python-nose-exclude
  * python-tox
  * python-twine
  * python-wheel
- Update 0001-Don-t-pin-dependency-to-exact-version.patch
- Disable tests for now, as there require network
* Thu Sep 11 2014 toddrme2178@gmail.com
- Remove upstreamed 0001-Don-t-install-dummyserver-into-site-packages.patch
- Rebase 0001-Don-t-pin-dependency-to-exact-version.patch and
  urllib3-test-no-coverage.patch
- Update to version 1.9 (2014-07-04)
  * Shuffled around development-related files.
    If you're maintaining a distro package of urllib3, you may need
    to tweak things. (Issue #415)
  * Unverified HTTPS requests will trigger a warning on the first
    request. See our new security documentation for details.
    (Issue #426)
  * New retry logic and urllib3.util.retry.Retry configuration
    object. (Issue #326)
  * All raised exceptions should now wrapped in a
    urllib3.exceptions.HTTPException-extending exception.
    (Issue #326)
  * All errors during a retry-enabled request should be wrapped in
    urllib3.exceptions.MaxRetryError, including timeout-related
    exceptions which were previously exempt. Underlying error is
    accessible from the .reason propery. (Issue #326)
  * urllib3.exceptions.ConnectionError renamed to
    urllib3.exceptions.ProtocolError. (Issue #326)
  * Errors during response read (such as IncompleteRead) are now
    wrapped in urllib3.exceptions.ProtocolError. (Issue #418)
  * Requesting an empty host will raise
    urllib3.exceptions.LocationValueError. (Issue #417)
  * Catch read timeouts over SSL connections as
    urllib3.exceptions.ReadTimeoutError. (Issue #419)
  * Apply socket arguments before connecting. (Issue #427)
- Update to version 1.8.3 (2014-06-23)
  * Fix TLS verification when using a proxy in Python 3.4.1.
    (Issue #385)
  * Add disable_cache option to urllib3.util.make_headers.
    (Issue #393)
  * Wrap socket.timeout exception with
    urllib3.exceptions.ReadTimeoutError. (Issue #399)
  * Fixed proxy-related bug where connections were being reused
    incorrectly. (Issues #366, #369)
  * Added socket_options keyword parameter which allows to define
    setsockopt configuration of new sockets. (Issue #397)
  * Removed HTTPConnection.tcp_nodelay in favor of
    HTTPConnection.default_socket_options. (Issue #397)
  * Fixed TypeError bug in Python 2.6.4. (Issue #411)
- Update to version 1.8.2 (2014-04-17)
  * Fix urllib3.util not being included in the package.
- Update to version 1.8.1 (2014-04-17)
  * Fix AppEngine bug of HTTPS requests going out as HTTP.
    (Issue #356)
  * Don't install dummyserver into site-packages as it's only
    needed for the test suite. (Issue #362)
  * Added support for specifying source_address. (Issue #352)
* Thu Mar 20 2014 speilicke@suse.com
- Update to version 1.8:
  * Improved url parsing in urllib3.util.parse_url (properly parse '@' in
    username, and blank ports like 'hostname:').
  * New urllib3.connection module which contains all the HTTPConnection
    objects.
  * Several urllib3.util.Timeout-related fixes. Also changed constructor
    signature to a more sensible order. [Backwards incompatible]
    (Issues #252, #262, #263)
  * Use backports.ssl_match_hostname if it's installed. (Issue #274)
  * Added .tell() method to urllib3.response.HTTPResponse which
    returns the number of bytes read so far. (Issue #277)
  * Support for platforms without threading. (Issue #289)
  * Expand default-port comparison in HTTPConnectionPool.is_same_host
    to allow a pool with no specified port to be considered equal to to an
    HTTP/HTTPS url with port 80/443 explicitly provided. (Issue #305)
  * Improved default SSL/TLS settings to avoid vulnerabilities.
    (Issue #309)
  * Fixed urllib3.poolmanager.ProxyManager not retrying on connect errors.
    (Issue #310)
  * Disable Nagle's Algorithm on the socket for non-proxies. A subset of requests
    will send the entire HTTP request ~200 milliseconds faster; however, some of
    the resulting TCP packets will be smaller. (Issue #254)
  * Increased maximum number of SubjectAltNames in urllib3.contrib.pyopenssl
    from the default 64 to 1024 in a single certificate. (Issue #318)
  * Headers are now passed and stored as a custom
    urllib3.collections_.HTTPHeaderDict object rather than a plain dict.
    (Issue #329, #333)
  * Headers no longer lose their case on Python 3. (Issue #236)
  * urllib3.contrib.pyopenssl now uses the operating system's default CA
    certificates on inject. (Issue #332)
  * Requests with retries=False will immediately raise any exceptions without
    wrapping them in MaxRetryError. (Issue #348)
  * Fixed open socket leak with SSL-related failures. (Issue #344, #348)
- Run testsuite (without coverage)
  + urllib3-test-no-coverage.patch
- Fix superfluous dependencies and allow later version
  + 0001-Don-t-pin-dependency-to-exact-version.patch
- Drop dummyserver module, this really is documentation
  + 0001-Don-t-install-dummyserver-into-site-packages.patch
* Fri Nov 15 2013 p.drouand@gmail.com
- Update to version 1.7.1
  + Added granular timeout support with new urllib3.util.Timeout class.
    (Issue #231)
  + Fixed Python 3.4 support. (Issue #238)
- Changes from 1.7
  + More exceptions are now pickle-able, with tests. (Issue #174)
  + Fixed redirecting with relative URLs in Location header. (Issue #178)
  + Support for relative urls in Location: ... header. (Issue #179)
  + urllib3.response.HTTPResponse now inherits from io.IOBase for bonus
    file-like functionality. (Issue #187)
  + Passing assert_hostname=False when creating a HTTPSConnectionPool will
    skip hostname verification for SSL connections. (Issue #194)
  + New method urllib3.response.HTTPResponse.stream(...) which acts as a
    generator wrapped around .read(...). (Issue #198)
  + IPv6 url parsing enforces brackets around the hostname. (Issue #199)
  + Fixed thread race condition in
    urllib3.poolmanager.PoolManager.connection_from_host(...) (Issue #204)
  + ProxyManager requests now include non-default port in Host: ...
    header. (Issue #217)
  + Added HTTPS proxy support in ProxyManager. (Issue #170 #139)
  + New RequestField object can be passed to the fields=... param which
    can specify headers. (Issue #220)
  + Raise urllib3.exceptions.ProxyError when connecting to proxy fails.
    (Issue #221)
  + Use international headers when posting file names. (Issue #119)
  + Improved IPv6 support. (Issue #203)
- Add documentation from tarball
* Sun Jul 14 2013 alexandre@exatati.com.br
- Initial package (1.6) for openSUSE.
